@@ -10,7 +10,7 @@
 use 5.014;
 use utf8;
 package App::SpreadRevolutionaryDate::Config;
-$App::SpreadRevolutionaryDate::Config::VERSION = '0.41';
+$App::SpreadRevolutionaryDate::Config::VERSION = '0.42';
 # ABSTRACT: Companion class of L<App::SpreadRevolutionaryDate>, to handle configuration file and command line arguments, subclass of L<AppConfig>.
 
 use Moose;
@@ -73,9 +73,13 @@ sub new {
                                       'mastodon' => {ARGCOUNT => ARGCOUNT_NONE, ALIAS => 'm'},
                                       'freenode' => {ARGCOUNT => ARGCOUNT_NONE, ALIAS => 'f'},
                                       'liberachat' => {ARGCOUNT => ARGCOUNT_NONE, ALIAS => 'lt'});
-  $config_targets->parse_file($filename);
   # Rewind command line arguments and process them
   @ARGV = @orig_argv;
+  $config_targets->parse_file($filename);
+
+  # Record targets in configuration file to be bypassed if defined in command line arguments
+  my @config_file_targets =  @{$config_targets->targets};
+
   $config_targets->parse_command_line;
 
   # Add targets defined with targets option
@@ -101,6 +105,9 @@ sub new {
     $config_targets->freenode(1);
     $config_targets->liberachat(1);
   }
+  if (scalar @targets > scalar @config_file_targets) {
+    @targets = splice @targets, scalar @config_file_targets - scalar @targets, scalar @targets;
+  }
 
   # Guess attributes for each target associated class
   my %target_attributes;
@@ -392,7 +399,7 @@ App::SpreadRevolutionaryDate::Config - Companion class of L<App::SpreadRevolutio
 
 =head1 VERSION
 
-version 0.41
+version 0.42
 
 =head1 METHODS
 
